#include "orbsvcs/Event/EC_Supplier_Filter_Builder.h"



TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_EC_Supplier_Filter_Builder::~TAO_EC_Supplier_Filter_Builder ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
